<?php

namespace Drupal\eca_render\Form;

use Drupal\Core\Form\BaseFormIdInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form object for custom forms defined by ECA.
 */
class EcaCustomForm implements BaseFormIdInterface {

  /**
   * The custom form ID.
   *
   * @var string
   */
  protected string $formId;

  /**
   * Constructs a new EcaCustomForm object.
   *
   * @param string $form_id
   *   The custom form ID. It must be prefixed with "eca_custom_".
   */
  public function __construct(string $form_id) {
    if (!(mb_strpos($form_id, 'eca_custom_') === 0)) {
      throw new \InvalidArgumentException("The provided custom form ID must start with \"eca_custom_\". It cannot be used for other form IDs.");
    }
    $this->formId = $form_id;
  }

  /**
   * {@inheritdoc}
   */
  public function getBaseFormId(): ?string {
    return 'eca_custom';
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return $this->formId;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {}

}
